library(mallet)
library(ggplot2)

setwd("/Users/mimno/Documents/Presentations/CUNY")

n.topics <- 30

documents <- read.table("sotu_years.txt", colClasses=c("character", "numeric", "character"), col.names=c("id", "year", "text"), sep="\t", quote="")

mallet.instances <- mallet.import(documents$id, documents$text, "sotu_stop.txt", token.regexp = "\\p{L}[\\p{L}\\p{P}]+\\p{L}")

## Create a topic trainer object.
topic.model <- MalletLDA(num.topics=n.topics)

topic.model$loadDocuments(mallet.instances)

topic.model$setAlphaOptimization(20, 50)

## Now train a model.
##  We can specify the number of iterations. Here we'll use a large-ish round number.
topic.model$train(100)

## NEW: run through a few iterations where we pick the best topic for each token, 
##  rather than sampling from the posterior distribution.
topic.model$maximize(50)

doc.topics <- mallet.doc.topics(topic.model, smoothed=T, normalized=T)
topic.words <- mallet.topic.words(topic.model, smoothed=T, normalized=T)

p <- ggplot(data.frame(Year = documents$year, Topic = doc.topics[,9]), aes(Year, Topic))
p + geom_point() + stat_smooth()

